.. _introduction:

************
Introduction
************

Champollion is a :term:`Sphinx` extension which provides a way to parse
:term:`Javascript` source code and produce automatic API documentation from
:term:`reStructuredText` docstrings.


.. seealso::

    `Who is Champollion? <https://en.wikipedia.org/wiki/Jean-Fran%C3%A7ois_Champollion>`_
